Grism-based Spectrograph Modeling
=================================

This module implements an ad-hoc grism-based spectrograph optical model. It
provides a flexible chromatic mapping between the input focal plane and the
output detector plane, based on an effective simplified ray-tracing model of
the key optical elements defining the spectrograph (collimator, prism, grating,
camera), described by a restricted number of physically-motivated distortion
parameters.

* `Code repository <https://gitlab.in2p3.fr/ycopin/spectrogrism/>`_
* `Documentation <https://ycopin.pages.in2p3.fr/spectrogrism/>`_
